==> kmyfirewall_1.0.orig.tar.gz: kmyfirewall-1.0/kmyfirewall/ruleoptionplugins/state_option/kmfruleeditorstate.h <==
/***************************************************************************
 begin                : Wed Mar 13 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : chubinger@gmail.com
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFRULEEDITORSTATE_H
#define KMFRULEEDITORSTATE_H
#include "kmyfirewallruleeditorstate.h"

#include <qwidget.h>

class IPTRule;
/**
  *@author Christian Hubinger
  */

class KMFRuleEditorState : public KMyFirewallRuleEditorState {
	Q_OBJECT
public:
	KMFRuleEditorState( QWidget *parent = 0, const char *name = 0, WFlags fl = 0 );
	~KMFRuleEditorState();
	QPtrList<QString>* options;

	void loadRule( IPTRule* );
public slots:    // Public slots
	void slotOk();
	void readRuleConfig();
	void slotHelp();
	void reject();

private:
	IPTRule* m_rule;

signals:
	void sigAddRuleOpt( QString *, QPtrList<QString> * );
	void sigHideMe();
};

#endif

==> kmyfirewall_1.1.1.orig.tar.gz: kmyfirewall-1.1.1/kmyfirewall/ruleoptionplugins/state_option/kmfruleeditorstate.h <==
/***************************************************************************
 begin                : Wed Mar 13 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : chubinger@irrsinnig.org
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFRULEEDITORSTATE_H
#define KMFRULEEDITORSTATE_H
#include "kmyfirewallruleeditorstate.h"

#include <qwidget.h>
namespace KMF {
class IPTRule;
/**
  *@author Christian Hubinger
  */

class KMFRuleEditorState : public KMyFirewallRuleEditorState {
	Q_OBJECT
public:
	KMFRuleEditorState( QWidget *parent = 0, const char *name = 0, WFlags fl = 0 );
	~KMFRuleEditorState();
	QPtrList<QString>* options;

	void loadRule( IPTRule* );
public slots:    // Public slots
	void slotOk();
	void readRuleConfig();
	void slotHelp();
	void reject();

private:
	IPTRule* m_rule;

signals:
/*	void sigAddRuleOpt( QString*, QPtrList<QString>* );
	void sigAddTargetOpt( QString*, QPtrList<QString>* );*/
	void sigHideMe();
};
}
#endif
